@@ -22,12 +22,11 @@ def bound(val, min_val, max_val):
     return min(max(val, min_val), max_val)
 
 
-def log_run_time(action):
-    def decorator(func):
-        def inner_func(*args, **kwargs):
-            start = time.time()
-            result = func(*args, **kwargs)
-            logger.info("action [%s] cost [%f]", action, time.time() - start)
-            return result
-        return inner_func
-    return decorator
+def log_exec_time(func):
+    def inner_func(*args, **kwargs):
+        start = time.time()
+        result = func(*args, **kwargs)
+        logger.info("function [%s], args[%s], kwargs[%s] cost[%.2f]",
+                    func.__name__, args, kwargs, time.time() - start)
+        return result
+    return inner_func
